159,014 Commits over 4,566 Days - 1.45cph!

24 Minutes Ago
Release pad run/crouch toggles when keyboard/mouse is used, so a pad latch can't carry into keyboard play
33 Minutes Ago
Various prefab fixes
34 Minutes Ago
Fix editor NRE debug
42 Minutes Ago
mag_drop_fixes -> main
42 Minutes Ago
Stop SpaceLR and M15 mags sticking to the bone
1 Hour Ago
Gun attack effects can now be recycled before their tail sound finishes, means we only have to warm up half the amount we'd need to
1 Hour Ago
Cleanup
1 Hour Ago
merge from main
1 Hour Ago
Skip the gamepad vehicle action set lookup when no Steam Input controller is active
1 Hour Ago
Only send waterwheel network updates when its actually changed (at low speed) Saves ~76 B per skipped update per nearby player
1 Hour Ago
Merge from main
1 Hour Ago
Clear potential stale gamepad inventory cursors in edit mode
1 Hour Ago
Tooltip bind lookup fix
1 Hour Ago
Added replayInPlace to EffectRecycle, lets us flag effects that can be replayed in place instead of popping and retiring a pooled copy every time Applied to AK first and 3rd person shell eject effects for now, ~0.13ms -> ~0.04ms per shot Also means we'll only have to prewarm a handful of shell particle prefabs for all the guns
2 Hours Ago
Adding dweller mace viewmodel rig
2 Hours Ago
Merge from main
2 Hours Ago
merge from main
2 Hours Ago
Use Facepunch.Steamworks GetPngAnalogActionGlyph for stick/trigger glyphs, remove the now unnecessary hacky workaround
2 Hours Ago
Merge from main
2 Hours Ago
Fix motion vector pass being culled when ocean is present
2 Hours Ago
Merge from main (actually latest this time)
3 Hours Ago
Updating tattoo rig with updated mesh
3 Hours Ago
Merge from main, and fix MapInterface marker conflict
3 Hours Ago
Merge from render_pipeline_testing
3 Hours Ago
Merge from render_pipeline_testing
3 Hours Ago
Merge from fp_sw_glyph_fixes
3 Hours Ago
Update Facepunch.Steamworks: fix Steam Input glyph origin buffer overflow, add GetPngAnalogActionGlyph, cache action set handles
3 Hours Ago
Forward jump down animations for cow and sheep
3 Hours Ago
Updating flail viewmodel rig
4 Hours Ago
Rebind rendertarget to camera target after rendergraph and move SetupCameraProperties back
Rin
4 Hours Ago
Handmade SMG damage Increased 20 > 21
6 Hours Ago
▄▆▄▆▅█▋▍ ▉▋▆ ▍▉▇▅█▅▊ ▉█▍▄▇ ▆▍ ▉▇ █▆█ ▌▋▇▆▅▇▄▅▄▄ ▋▌▉▉▋ ▍▍ ▊▅▋▌ ▌▍█▆ ▄▍▌ ▇▉▅▇▊▄▌█ ▊▇▅▌▇▍▊█▊▅█▋▉▍▊▊▆▉ ▊▄▌ ▌▍▅▇▅▋▉ ▍█ ▅▉▊▇▆▊█▆▇▌▆█▋▅▉▅▇▇▍█▄▅█▌▉▋▇▄▉▆▆▅▉▆▍▍▄▅▋▄▅ ▍▆▋▋▇▄▋▉▅ ▌▇▉█▇▄▄▌ ▋▉▆█▋▄▊▅▌ ▉▆▊▅▅▊▌▆▅ ▌▊▄▆▊▊█▇ █▌▉ ▄▍▌▌▆█▅▋
Today
Merge from car_spawning_prefill
Today
Round up the amount of filled slots, so a 5 slot engine gets 3 prefilled instead of 2
Today
Manifest update
Today
Merge from main
Today
Merge from prototype_draggable_markers Can now drag map markers on the map screen with MMB
Today
▉▊▄▅▋▌ █▇▆▌▉█▍ ▍▄▉ ▄▄▇▋▆█▄
Today
▉▄▊▊▌▅ ▉▇▍▅ ▄▌▊▍
Today
Merge from terrain_watermap_test
Today
Remove watermap texture2D creation on procedural map, saves ~89.5MB on 4k map
Today
Merge from livestock_digestion_boost
Today
Cleanup
Today
Merge fixes Apply the dung boost the whole time an animal is eating an item from the trough, not just when the item is consumed (caused gaps in boost coverage) Animals eat a booster item from the trough over any other item
Today
Merge from main (sketchy merge, need to revert any behaviour changes)
Today
Fixed EffectParentToWeaponBone 128B alloc per effect spawn
Today
When in first person, don't spawn effects with HideIfOwnerFirstPerson instead of spawning and hiding them right away Also fixed the 128B alloc in HideIfOwnerFirstPerson.OnEnable Saves 0.1ms when firing the AK
Today
Merge from hardcore_changes_nov_26
Today
Reduced the amount of pooled pilot codelock 200 -> 25 Keylock 1 -> 50
Today
Reduced the amount of pooled blowpipe dart projectiles 100 -> 4